@@ -4,7 +4,7 @@
 import os
 
 def main():
-    help = os.path.join(os.path.abspath(os.path.dirname(__file__)), 'help')
+    help = os.path.join(os.path.abspath(os.path.dirname(__file__)), 'README.md')
     with open(help, 'r') as f:
         print(f.read())
 
